==> applet-spring-3.1.1-sources.jar: cn/sinozg/applet/common/utils/DowUtil.java <==
/*
 * Copyright (C) 2020-2024, Xie YuBin
 * The GNU Free Documentation License covers this file. The original version
 * of this license can be found at http://www.gnu.org/licenses/gfdl.html.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Free Documentation License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Free Documentation License for more details.
 *
 * You should have received a copy of the GNU Free Documentation License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package cn.sinozg.applet.common.utils;

import cn.sinozg.applet.common.exception.CavException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.HttpHeaders;

import jakarta.servlet.http.HttpServletResponse;
import java.io.BufferedOutputStream;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.util.function.Consumer;

/**
 * 文件下载 工具类
 * @author xieyubin
 * @Description
 * @Copyright Copyright (c) 2024
 * @since 2024-01-05 17:10
 */
public class DowUtil {

    private static final Logger log = LoggerFactory.getLogger(DowUtil.class);

    private DowUtil() {
    }
    /**
     * 下载指定资源
     * @param response HttpServletResponse
     * @param fileName 文件名
     * @param bs 输出的字节
     * @param consumer 执行方法
     */
    public static void download(HttpServletResponse response, String fileName, byte[] bs, Consumer<BufferedOutputStream> consumer)  {
        setResponse(response, fileName, bs);
        try (OutputStream os = response.getOutputStream();
             BufferedOutputStream bos = new BufferedOutputStream(os)) {
            if (bs != null) {
                bos.write(bs);
            }
            if (consumer != null) {
                consumer.accept(bos);
            }
        } catch (Exception e) {
            log.error("下载资源错误。", e);
            throw new CavException("BIZ000100023");
        }
    }

    /**
     * 设置 response
     * @param response response
     * @param fileName 文件名
     * @param bs 要输出的流
     */
    public static void setResponse (HttpServletResponse response, String fileName, byte[] bs){
        String charset = StandardCharsets.UTF_8.name();
        response.reset();
        response.setCharacterEncoding(charset);
        response.setHeader(HttpHeaders.CONTENT_ENCODING, charset);
        response.setContentType(FileUtil.fileType(fileName));
        if (bs != null) {
            response.setIntHeader(HttpHeaders.CONTENT_LENGTH, bs.length);
        }
        try {
            response.setHeader(HttpHeaders.CONTENT_DISPOSITION, "attachment;filename=" + URLEncoder.encode(fileName, charset));
        } catch (Exception ignored) {
        }
    }
}

==> applet-spring-3.2.0-sources.jar: cn/sinozg/applet/common/utils/DowUtil.java <==
/*
 * Copyright (C) 2020-2024, Xie YuBin
 * The GNU Free Documentation License covers this file. The original version
 * of this license can be found at http://www.gnu.org/licenses/gfdl.html.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Free Documentation License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Free Documentation License for more details.
 *
 * You should have received a copy of the GNU Free Documentation License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package cn.sinozg.applet.common.utils;

import cn.sinozg.applet.common.exception.CavException;
import cn.sinozg.applet.common.function.ConsumerException;
import jakarta.servlet.http.HttpServletResponse;
import java.io.BufferedOutputStream;
import java.io.OutputStream;
import java.nio.charset.StandardCharsets;
import java.util.function.Consumer;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.HttpHeaders;

/**
 * 文件下载 工具类
 * @author xieyubin
 * @Description
 * @Copyright Copyright (c) 2024
 * @since 2024-01-05 17:10
 */
public class DowUtil {

    private static final Logger log = LoggerFactory.getLogger(DowUtil.class);

    private DowUtil() {
    }
    /**
     * 下载指定资源
     * @param response HttpServletResponse
     * @param fileName 文件名
     * @param bs 输出的字节
     * @param consumer 执行方法
     */
    public static void download(HttpServletResponse response, String fileName, byte[] bs, Consumer<BufferedOutputStream> consumer)  {
        downloadExp(response, fileName, bs, bos -> {
            if (consumer != null) {
                consumer.accept(bos);
            }
        });
    }
    /**
     * 下载指定资源 有异常
     * @param response HttpServletResponse
     * @param fileName 文件名 不传则不设置response
     * @param bs 输出的字节
     * @param consumer 执行方法 带异常
     */
    public static void downloadExp(HttpServletResponse response, String fileName, byte[] bs, ConsumerException<BufferedOutputStream> consumer)  {
        if (StringUtils.isNotBlank(fileName)) {
            setResponse(response, fileName, bs);
        }
        try (OutputStream os = response.getOutputStream();
             BufferedOutputStream bos = new BufferedOutputStream(os)) {
            if (bs != null) {
                bos.write(bs);
            }
            if (consumer != null) {
                consumer.accept(bos);
            }
        } catch (Exception e) {
            log.error("下载资源错误。", e);
            throw new CavException("BIZ000100023");
        }
    }


    /**
     * 设置 response
     * @param response response
     * @param fileName 文件名
     * @param bs 要输出的流
     */
    public static void setResponse (HttpServletResponse response, String fileName, byte[] bs){
        String charset = StandardCharsets.UTF_8.name();
        response.reset();
        response.setCharacterEncoding(charset);
        response.setHeader(HttpHeaders.CONTENT_ENCODING, charset);
        response.setContentType(FileUtil.fileType(fileName));
        if (bs != null) {
            response.setIntHeader(HttpHeaders.CONTENT_LENGTH, bs.length);
        }
        response.setHeader(HttpHeaders.CONTENT_DISPOSITION, "attachment;filename=" + FileUtil.encodeName(fileName, charset));
    }
}
